Client

Struct Client 

pub struct Client { /* private fields */ }
Async client for the BLEFYI API.

Implementations

Source

impl Client

pub fn new() -> Self

Creates a new client with the default base URL.

pub fn with_base_url(base_url: &str) -> Self

Creates a new client with a custom base URL.

pub async fn search(&self, query: &str) -> Result<SearchResult, BleFyiError>

Search across BLE chips, profiles, and glossary terms.

pub async fn chip(&self, slug: &str) -> Result<ChipDetail, BleFyiError>

Get details for a BLE chip by slug.

pub async fn profile(&self, slug: &str) -> Result<ProfileDetail, BleFyiError>

Get details for a GATT profile by slug.

pub async fn version(&self, slug: &str) -> Result<VersionDetail, BleFyiError>

Get details for a Bluetooth version by slug.

pub async fn beacon(&self, slug: &str) -> Result<BeaconDetail, BleFyiError>

Get details for a beacon type by slug.

pub async fn usecase(&self, slug: &str) -> Result<UsecaseDetail, BleFyiError>

Get details for a BLE use case by slug.

pub async fn manufacturer( &self, slug: &str, ) -> Result<ManufacturerDetail, BleFyiError>

Get details for a manufacturer by slug.

pub async fn glossary_term( &self, slug: &str, ) -> Result<GlossaryTerm, BleFyiError>

Get a glossary term by slug.

pub async fn compare( &self, slug_a: &str, slug_b: &str, ) -> Result<CompareResult, BleFyiError>

Compare two BLE chips.

pub async fn random(&self) -> Result<ChipDetail, BleFyiError>

Get a random BLE chip.